@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Die;
 use vars '$VERSION';
-$VERSION = '1.16';
+$VERSION = '1.18';
 
 use base 'Exporter';
 
@@ -16,8 +16,10 @@ our @EXPORT = qw/die_decode/;
 use POSIX  qw/locale_h/;
 
 
-sub die_decode($)
-{   my @text   = split /\n/, $_[0];
+sub die_decode($%)
+{   my ($text, %args) = @_;
+
+    my @text   = split /\n/, $text;
     @text or return ();
     chomp $text[-1];
 
@@ -51,10 +53,11 @@ sub die_decode($)
     $opt{classes} = [ 'perl', (@stack ? 'confess' : 'die') ];
 
     my $reason
-      = @{$opt{stack}} ? ($opt{errno} ? 'ALERT' : 'PANIC')
-      :                  ($opt{errno} ? 'FAULT' : 'ERROR');
+      = $opt{errno} ? 'FAULT'
+      : @stack      ? 'PANIC'
+      :               $args{on_die} || 'ERROR';
 
-    ($dietxt, \%opt, $reason, join("\n",@msg));
+    ($dietxt, \%opt, $reason, join("\n", @msg));
 }
 
 "to die or not to die, that's the question";
